.. _source:

.. raw:: html

    <br><br>

.. title:: source


**president package**

.. raw:: html

    <br>

.. autosummary::
    :toctree: 
    :template: module.rst

    kamer.obj		object
    kamer.req		request
    kamer.run		handler
    kamer.slg		slogan
    kamer.sui		suicide stats
    kamer.trt		torture definition
    kamer.wsd		wisdom
